@@ -1,5 +1,6 @@
 package JMAP::Validation::Checks::Number;
 
+use JMAP::Validation;
 use JMAP::Validation::Tests::Number;
 use Test2::Bundle::Extended;
 
@@ -11,9 +12,17 @@ our $is_number = validator(sub {
   return (ref($params{got}) || '') eq 'JSON::Typist::Number';
 });
 
-our $is_number_or_null = in_set(
-  $is_number,
-  not_in_set(D()),
-);
+our $is_number_or_null = validator(sub {
+  my (%params) = @_;
+
+ if (defined $params{got}) {
+   return unless JMAP::Validation::validate(
+     $params{got},
+     $is_number,
+   );
+ }
+
+ return 1;
+});
 
 1;
